@@ -300,7 +300,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
     }
 
     QGridLayout *layout = new QGridLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     if (!mSidebarView) {
         layout->addWidget(mQuickSearch, 0, 0, 1, 2);
     }
